unit MainForm;

interface

uses
  SysUtils, Classes,
  QForms, QStdCtrls, QControls, QExtCtrls, QDialogs,
  {$IFDEF MSWINDOWS} Windows, ShellApi, {$ENDIF}
  mtrDesigner, mtrView, mtrExcelView, mtrHtmlView, mtrRtfView;

type
  TfmMain = class(TForm)
    btConnect: TButton;
    btDisconnect: TButton;
    btStart: TButton;
    btSchema: TButton;
    rgRpt: TRadioGroup;
    btTemplate: TButton;
    gbView: TGroupBox;
    rbExcel: TRadioButton;
    rbHTML: TRadioButton;
    rbRTF: TRadioButton;
    mtrDesigner: TmtrDesigner;
    mtrExcelView: TmtrExcelView;
    mtrHtmlView: TmtrHtmlView;
    mtrRtfView: TmtrRtfView;
    btAbout: TButton;
    procedure btConnectClick(Sender: TObject);
    procedure btDisconnectClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure btStartClick(Sender: TObject);
    procedure btSchemaClick(Sender: TObject);
    procedure rgRptClick(Sender: TObject);
    procedure btTemplateClick(Sender: TObject);
    procedure rbExcelClick(Sender: TObject);
    procedure rbHTMLClick(Sender: TObject);
    procedure rbRTFClick(Sender: TObject);
    procedure btAboutClick(Sender: TObject);
  private
    { Private declarations }
    FPath: string;
  public
    { Public declarations }
  end;

var
  fmMain: TfmMain;

implementation

uses Data, LoginForm;

const
  SchemaArr: array [0..6] of string = (
    'list1',
    'masterdetail1',
    'masterdetail2',
    'crosstab1',
    'chart1',
    'chart2',
    'complex1'
    );

{$R *.xfm}

procedure TfmMain.FormCreate(Sender: TObject);
var
  p: integer;
begin
  //locate demo shared directory
{$IFDEF MSWINDOWS}
  FPath := AnsiUpperCase(Application.ExeName);
  p := Pos('\DEMOS\', FPath);
  FPath := Copy(FPath, 1, p) + 'DEMOS\SHARED\';
{$ENDIF}
{$IFDEF LINUX}
  FPath := Application.ExeName;
  p := Pos('/demos/', FPath);
  FPath := Copy(FPath, 1, p) + 'demos/shared/';
{$ENDIF}
  mtrExcelView.TemplateDir := FPath;
  mtrHtmlView.TemplateDir := FPath;
  mtrRtfView.TemplateDir := FPath;
{$IFDEF LINUX}
  mtrHtmlView.ViewApplication := 'konqueror';
  mtrHtmlView.EditApplication := 'konqueror';
{$ENDIF}
end;

procedure TfmMain.btConnectClick(Sender: TObject);
var
  db_name, user_name, password: string;
begin
{$IFDEF MSWINDOWS}
  db_name := FPath + 'DBDEMOS.GDB';
{$ENDIF}
{$IFDEF LINUX}
  db_name := FPath + 'dbdemos.gdb';
{$ENDIF}
  user_name := 'SYSDBA';
  if fmLogin.Execute(db_name, user_name, password) then begin
    dmMain.Connect(db_name, user_name, password);
    btConnect.Enabled := false;
    btDisconnect.Enabled := true;
    btStart.Enabled := true;
    btSchema.Enabled := true;
    btTemplate.Enabled := true;
    rbExcel.Checked := true;
    dmMain.mtrClient.Viewer := mtrExcelView;
  end;
end;

procedure TfmMain.btDisconnectClick(Sender: TObject);
begin
  dmMain.Disconnect;
  btConnect.Enabled := true;
  btDisconnect.Enabled := false;
  btStart.Enabled := false;
  btSchema.Enabled := false;
  btTemplate.Enabled := false;
end;

procedure TfmMain.btStartClick(Sender: TObject);
begin
  dmMain.mtrClient.LoadFromFile(FPath + SchemaArr[rgRpt.ItemIndex] + '.config');

  dmMain.mtrClient.Params.Clear;

  if rgRpt.ItemIndex = 2 then begin
    // add parameters for "Master/Detail wit parameters" report
    dmMain.mtrClient.Params.Add('rpt_name', 'Orders');
    dmMain.mtrClient.Params.Add('company', 'K%');
  end;
  if rgRpt.ItemIndex in [3,5,6] then begin
    // add parameter for "Cross-tabulated" and "Complex" reports
    dmMain.mtrClient.Params.Add('vendor_no', 7382);
  end;

  dmMain.mtrClient.Execute;
end;

procedure TfmMain.btSchemaClick(Sender: TObject);
begin
  mtrDesigner.FileName := FPath + SchemaArr[rgRpt.ItemIndex] + '.config';
  mtrDesigner.ShowDesigner;
end;

procedure TfmMain.rgRptClick(Sender: TObject);
begin
  if rgRpt.ItemIndex in [3,4,5,6] then begin
    rbExcel.Checked := true;
    rbHTML.Enabled := false;
    rbRTF.Enabled := false;
  end
  else begin
    rbHTML.Enabled := true;
    rbRTF.Enabled := true;
  end;
end;

procedure TfmMain.btTemplateClick(Sender: TObject);
var
  s: string;
begin
  s := FPath + SchemaArr[rgRpt.ItemIndex];
{$IFDEF MSWINDOWS}
  if rbExcel.Checked then begin
    ShellExecute(HWND(nil), 'Open', PChar(s + '.xlt'), nil, nil, SW_SHOWNORMAL);
  end
  else if rbHTML.Checked then begin
    ShellExecute(HWND(nil), 'Edit', PChar(s + '.htm'), nil, nil, SW_SHOWNORMAL);
  end
  else if rbRTF.Checked then begin
    ShellExecute(HWND(nil), 'Open', PChar(s + '.rtf'), nil, nil, SW_SHOWNORMAL);
  end;
{$ENDIF}
end;

procedure TfmMain.rbExcelClick(Sender: TObject);
begin
  dmMain.mtrClient.Viewer := mtrExcelView;
end;

procedure TfmMain.rbHTMLClick(Sender: TObject);
begin
  dmMain.mtrClient.Viewer := mtrHtmlView;
end;

procedure TfmMain.rbRTFClick(Sender: TObject);
begin
  dmMain.mtrClient.Viewer := mtrRtfView;
end;

procedure TfmMain.btAboutClick(Sender: TObject);
begin
  dmMain.ShowAbout;
end;

end.
