unit ReportServer;

interface

uses
  ComObj, ActiveX, ServerDBX_TLB, StdVcl, Classes, SqlExpr, mtrServer,
  mtrCustomServers, mtrGlobal;

type
  TReportServer = class(TAutoObject, IReportServer)
  private
    FConnection: TSQLConnection;
    FServer: TmtrDBXServer;
  protected
    { IReportServer }
    procedure Prepare(var AData: OleVariant); safecall;
    procedure Execute(var AData: OleVariant); safecall;
    procedure Connect(const ADatabase, AUser, APassword: WideString); safecall;
  public
    procedure AfterConstruction; override;
    procedure BeforeDestruction; override;
  end;

implementation

uses ComServ, Global;

{ TReportServer }

procedure TReportServer.AfterConstruction;
begin
  inherited;
  FConnection := TSQLConnection.Create(nil);
  FConnection.LoginPrompt := false;
  FServer := TmtrDBXServer.Create(nil);
  FServer.Connection := FConnection;
end;

procedure TReportServer.BeforeDestruction;
begin
  FConnection.Close;
  FServer.Free; FServer := nil;
  FConnection.Free; FConnection := nil;
  inherited;
end;

procedure TReportServer.Connect(const ADatabase, AUser,
  APassword: WideString);
begin
  FConnection.LoginPrompt := false;
  FConnection.ConnectionName := 'IBLocal';
  FConnection.DriverName := 'Interbase';
  FConnection.LibraryName := 'dbexpint.dll';
  FConnection.VendorLib := 'GDS32.DLL';
  FConnection.GetDriverFunc := 'getSQLDriverINTERBASE';
  FConnection.Params.Values['Database'] := ADatabase;
  FConnection.Params.Values['User_Name'] := AUser;
  FConnection.Params.Values['Password'] := APassword;
  FConnection.Open;
end;

procedure TReportServer.Prepare(var AData: OleVariant);
var
  stream: TMemoryStream;
begin
  stream := TMemoryStream.Create;
  try
    Global.OleVariant2MemoryStream(AData, stream);
    FServer.Prepare(stream);
    AData := Global.MemoryStream2OleVariant(stream);
  finally
    stream.Free;
  end;
end;

procedure TReportServer.Execute(var AData: OleVariant);
var
  stream: TMemoryStream;
begin
  stream := TMemoryStream.Create;
  try
    Global.OleVariant2MemoryStream(AData, stream);
    FServer.Execute(stream);
    AData := Global.MemoryStream2OleVariant(stream);
  finally
    stream.Free;
  end;
end;

initialization
  TAutoObjectFactory.Create(ComServer, TReportServer, Class_ReportServer,
    ciMultiInstance, tmApartment);
end.
