unit Data;

interface

uses
  SysUtils, Classes, QForms, QDialogs,
  mtrClient, mtrGlobal, orb_int, report_server, report_server_int;

type
  TdmMain = class(TDataModule)
    mtrClient: TmtrClient;
    procedure mtrClientGetData(ADataStream: TMemoryStream);
    procedure mtrClientGetSchemaData(ADataStream: TMemoryStream);
    procedure mtrClientPrintBand(const AMax, ACurrent: Integer;
      var AFinish: Boolean);
    procedure mtrClientAfterExecute(Sender: TObject);
  private
    { Private declarations }
    FServerIntf: IReportServer;
  public
    { Public declarations }
    procedure Connect(APath: string);
    procedure Disconnect;
    procedure ShowAbout;
  end;

var
  dmMain: TdmMain;
  dorb : IORB;

implementation

uses
  orb, poa_impl, poa_int, Global, About, Progress;


{$R *.xfm}

procedure TdmMain.Connect(APath: string);
var
  server_machine: string;
  params: TStrings;
  obj : IORBObject;
begin
  server_machine := 'inet:localhost:10001';
  if not InputQuery('Input', 'Server Machine', server_machine) then Abort;

  if dorb = nil then
    begin
      params := TStringList.Create;
      try
        params.add('-ORBBindAddr');
        params.add(server_machine);
        dorb := ORB_Init(params);
      finally
        params.free;
      end;
    end;
  obj := dorb.bind('IDL:ReportServer:1.0', server_machine);
  if obj = nil then Abort;
  FServerIntf := TReportServer._narrow(obj);
end;

procedure TdmMain.Disconnect;
begin
  FServerIntf := nil;
end;

procedure TdmMain.mtrClientGetSchemaData(ADataStream: TMemoryStream);
var
  value: TReportData;
begin
  StreamToOctetSeq(ADataStream, value, false);
  FServerIntf.Prepare(value);
  OctetSeqToStream(ADataStream, value);
end;

procedure TdmMain.mtrClientGetData(ADataStream: TMemoryStream);
var
  value: TReportData;
begin
  StreamToOctetSeq(ADataStream, value, false);
  FServerIntf.Execute(value);
  OctetSeqToStream(ADataStream, value);
end;

procedure TdmMain.ShowAbout;
begin
  fmAbout.ShowModal;
end;

procedure TdmMain.mtrClientPrintBand(const AMax, ACurrent: Integer;
  var AFinish: Boolean);
begin
  with fmProgress do begin
    ProgressBar.Max := AMax;
    ProgressBar.Position := ACurrent;
    if not Visible then begin
      Show;
      SetFocus;
    end;
    Application.ProcessMessages;
    AFinish := Cancel;
    Cancel := false;
  end;
end;

procedure TdmMain.mtrClientAfterExecute(Sender: TObject);
begin
  if fmProgress.Visible then fmProgress.Close;
end;

end.
