unit ServerForm;

interface

uses
  Classes, QForms, QStdCtrls, QControls, DB, SqlExpr,
  mtrServer, mtrCustomServers, orb_int,
  report_server, report_server_int;

type
  TfmServer = class(TForm)
    btStart: TButton;
    edPort: TEdit;
    procedure btStartClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

  TORBThread = class(TThread)
    procedure execute; override;
  end;

  TReportServer_impl = class(TReportServer_serv)
  private
    FConnection: TSQLConnection;
    FServer: TmtrDBXServer;
  protected
    procedure Prepare(var AData: TReportData); override;
    procedure Execute(var AData: TReportData); override;
  public
    procedure AfterConstruction; override;
    procedure BeforeDestruction; override;
  end;

var
  fmServer: TfmServer;
  dorb : IORB;
  th: TThread;

implementation

uses
  orb, poa_int, poa_impl, Global;

{$R *.xfm}

procedure TfmServer.btStartClick(Sender: TObject);
var
  obj : IORBObject;
  params : TStrings;
  p: IPOA;
begin
  params := TStringList.Create();
  try
    params.add('-ORBIIOPAddr');
    params.add(edPort.Text);
    dorb := ORB_Init(params);
    obj := dorb.resolve_initial_reference('RootPOA');
    p := TPOA_impl._narrow(obj);
    p.activate_object(TReportServer_impl.Create());
    p.the_POAManager.activate;
    btStart.Enabled := false;
    th := TORBThread.Create(true);
    th.FreeOnTerminate := true;
    th.Resume;
  finally
    params.free;
  end;
end;

{ TORBThread }

procedure TORBThread.execute;
begin
  dorb.run;
end;

{ TReportServer_impl }

procedure TReportServer_impl.AfterConstruction;
begin
  inherited;
  FConnection := TSQLConnection.Create(nil);
  FConnection.LoginPrompt := false;
{$IFDEF LINUX}
  FConnection.ConnectionName := 'IBLocal';
  FConnection.DriverName := 'INTERBASE';
  FConnection.GetDriverFunc := 'getSQLDriverINTERBASE';
  FConnection.LibraryName := 'libsqlib.so.1';
  FConnection.VendorLib := 'libgds.so';
  FConnection.Params.Values['Database'] := '/mnt/c/proj/mtrpt/demos/shared/dbdemos.gdb';
{$ENDIF}
{$IFDEF MSWINDOWS}
  FConnection.ConnectionName := 'IBLocal';
  FConnection.DriverName := 'Interbase';
  FConnection.GetDriverFunc := 'getSQLDriverINTERBASE';
  FConnection.LibraryName := 'dbexpint.dll';
  FConnection.VendorLib := 'GDS32.DLL';
  FConnection.Params.Values['Database'] := 'C:\PROJ\MTRPT\DEMOS\SHARED\DBDEMOS.GDB';
{$ENDIF}
  FConnection.Params.Values['User_Name'] := 'sysdba';
  FConnection.Params.Values['Password'] := '1';
  FServer := TmtrDBXServer.Create(nil);
  FServer.Connection := FConnection;
  FConnection.Open;
end;

procedure TReportServer_impl.BeforeDestruction;
begin
  FConnection.Close;
  FServer.Free; FServer := nil;
  FConnection.Free; FConnection := nil;
  inherited;
end;

procedure TReportServer_impl.Execute(var AData: TReportData);
var
  stream: TMemoryStream;
begin
  stream := TMemoryStream.Create;
  try
    OctetSeqToStream(stream, AData);
    FServer.Execute(stream);
    StreamToOctetSeq(stream, AData, false);
  finally
    stream.Free;
  end;
end;

procedure TReportServer_impl.Prepare(var AData: TReportData);
var
  stream: TMemoryStream;
begin
  stream := TMemoryStream.Create;
  try
    OctetSeqToStream(stream, AData);
    FServer.Prepare(stream);
    StreamToOctetSeq(stream, AData, false);
  finally
    stream.Free;
  end;
end;

end.
